@@ -22,7 +22,6 @@ from typing import (
 )
 
 from rx.core.typing import Observable
-import numpy as np
 
 
 Callback = Union[
@@ -518,9 +517,7 @@ class VideoFrame(Protocol):
     def input_height(self) -> int: ...
     def input_format(self) -> str: ...
     def to_buffer(self, options: Optional[ImageOptions] = None) -> bytes: ...
-    def to_numpy(
-        self, options: Optional[ImageOptions] = None
-    ) -> np.ndarray[Any, Any]: ...
+    def to_numpy(self, options: Optional[ImageOptions] = None) -> Any: ...
     def to_image(self, options: Optional[ImageOptions] = None) -> Any: ...
 
 
